@@ -21,16 +21,20 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include <stdio.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#include <sys/types.h>
+#endif
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
 
 #include "gst_private.h"
+#include "gstinfo.h"
 
-#include "gstlog.h"
 #include "gsttrace.h"
 
 static
@@ -66,7 +70,13 @@ gst_trace_new (gchar * filename, gint size)
 
   g_return_val_if_fail (trace != NULL, NULL);
   trace->filename = g_strdup (filename);
-  g_print ("opening '%s'\n", trace->filename);
+  GST_DEBUG ("opening '%s'\n", trace->filename);
+#ifndef S_IWUSR
+#define S_IWUSR S_IWRITE
+#endif
+#ifndef S_IRUSR
+#define S_IRUSR S_IREAD
+#endif
   trace->fd =
       open (trace->filename, O_RDWR | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR);
   perror ("opening trace file");
@@ -120,7 +130,7 @@ gst_trace_text_flush (GstTrace * trace)
   }
 
   for (i = 0; i < trace->bufoffset; i++) {
-    snprintf (str, STRSIZE, "%20" G_GINT64_FORMAT " %10d %10d %s\n",
+    g_snprintf (str, STRSIZE, "%20" G_GINT64_FORMAT " %10d %10d %s\n",
         trace->buf[i].timestamp,
         trace->buf[i].sequence, trace->buf[i].data, trace->buf[i].message);
     write (trace->fd, str, strlen (str));
@@ -278,7 +288,7 @@ gst_alloc_trace_set_flags_all (GstAllocTraceFlags flags)
   while (walk) {
     GstAllocTrace *trace = (GstAllocTrace *) walk->data;
 
-    g_print ("set flags on %p\n", trace);
+    GST_DEBUG ("set flags on %p\n", trace);
     gst_alloc_trace_set_flags (trace, flags);
 
     walk = g_list_next (walk);
