@@ -277,6 +277,7 @@ gst_entry_scheduler_loop_wrapper (int argc, char **argv)
   CothreadPrivate *priv = (CothreadPrivate *) argv;
   GstElement *element = priv->element;
 
+  priv->wait = WAIT_FOR_NOTHING;
   do {
     g_assert (priv->wait == WAIT_FOR_NOTHING);
     GST_LOG_OBJECT (SCHED (element), "calling loopfunc for element %s",
@@ -332,6 +333,7 @@ gst_entry_scheduler_chain_wrapper (int argc, char **argv)
   CothreadPrivate *priv = (CothreadPrivate *) argv;
   GstElement *element = priv->element;
 
+  priv->wait = WAIT_FOR_PADS;
   do {
     GstRealPad *pad = priv->schedule_pad;
 
@@ -397,6 +399,7 @@ gst_entry_scheduler_get_wrapper (int argc, char **argv)
   CothreadPrivate *priv = (CothreadPrivate *) argv;
   GstElement *element = priv->element;
 
+  priv->wait = WAIT_FOR_PADS;
   do {
     GstRealPad *pad = priv->schedule_pad;
 
@@ -870,10 +873,8 @@ static void
 gst_entry_scheduler_remove_element (GstScheduler * scheduler,
     GstElement * element)
 {
-  GstEntryScheduler *sched = GST_ENTRY_SCHEDULER (scheduler);
-
   if (GST_FLAG_IS_SET (element, GST_ELEMENT_DECOUPLED)) {
-    GST_INFO_OBJECT (sched, "decoupled element %s added, ignoring",
+    GST_INFO_OBJECT (scheduler, "decoupled element %s added, ignoring",
         GST_OBJECT_NAME (element));
     return;
   }
@@ -1159,18 +1160,14 @@ gst_entry_scheduler_show (GstScheduler * scheduler)
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  GstSchedulerFactory *factory;
+  if (!gst_scheduler_register (plugin, "entry" COTHREADS_NAME,
+          "A entry scheduler using " COTHREADS_NAME " cothreads",
+          GST_TYPE_ENTRY_SCHEDULER))
+    return FALSE;
 
   GST_DEBUG_CATEGORY_INIT (debug_scheduler, "entry" COTHREADS_NAME, 0,
       "entry " COTHREADS_NAME "scheduler");
 
-  factory = gst_scheduler_factory_new ("entry" COTHREADS_NAME,
-      "A entry scheduler using " COTHREADS_NAME " cothreads",
-      GST_TYPE_ENTRY_SCHEDULER);
-  if (factory == NULL)
-    return FALSE;
-
-  gst_plugin_add_feature (plugin, GST_PLUGIN_FEATURE (factory));
   return TRUE;
 }
 
