@@ -1,24 +1,15 @@
 #include <gst/gst.h>
 
 /* these caps all have a non empty intersection */
-GstStaticCaps sinkcaps = GST_STATIC_CAPS (
-  "video/mpeg, "
+GstStaticCaps sinkcaps = GST_STATIC_CAPS ("video/mpeg, "
     "mpegtype:int=1, "
-    "foo1:int=[20,40], "
-    "foo2:int=[20,40], "
-    "foo3:int=[10,20]"
-);
+    "foo1:int=[20,40], " "foo2:int=[20,40], " "foo3:int=[10,20]");
 
-GstStaticCaps mp1parsecaps = GST_STATIC_CAPS (
-  "video/mpeg, "
-    "mpegtype:int=1, "
-    "foo1:int=30, "
-    "foo2:int=[20,30], "
-    "foo3:int=[20,30]"
-);
+GstStaticCaps mp1parsecaps = GST_STATIC_CAPS ("video/mpeg, "
+    "mpegtype:int=1, " "foo1:int=30, " "foo2:int=[20,30], " "foo3:int=[20,30]");
 
-int 
-main (int argc, char *argv[]) 
+int
+main (int argc, char *argv[])
 {
   xmlDocPtr doc;
   xmlNodePtr parent;
@@ -34,7 +25,7 @@ main (int argc, char *argv[])
   parent = xmlNewChild (doc->xmlRootNode, NULL, "Capabilities1", NULL);
   gst_caps_save_thyself (caps, parent);
 
-  xmlDocDump(stdout, doc);
+  xmlDocDump (stdout, doc);
 
   return 0;
 }
